@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- encoding: UTF8 -*-
 
 #######################################################################
@@ -14,35 +14,13 @@ from simpleloggerplus import simpleloggerplus as log
 from subprocess import check_output, CalledProcessError
 from cryptdomainmgr.modules.common.cdmstatehelper import isReady
 from cryptdomainmgr.modules.common.cdmfilehelper import makeDir
+from cryptdomainmgr.modules.docker import dockerconfighelper as dch
 
 import docker
 
 defaultConfig = {'depends': 'dhparam, cert','dhparam': 'auto', 'cert': 'auto', 'dirint': 'auto', 'dirext': 'auto', 'dockersock': 'unix://var/run/docker.sock'}
 
 
-def dockerMyContainerID():
-    with open('/proc/self/cgroup', 'r') as f:
-        cgroup = {e.split(':')[0]:e.split(':') for e in f.read().splitlines()}
-        if 3 > len(cgroup['1']:
-            return ''
-        if 'docker' != cgroup['1'][1]:
-            return ''
-        return cgroup['1'][2]
-
-
-
-def dockerPathMap(dockersock, targetContainer, targetDirectory, sourceContainer, sourceDirectory):
-    client = docker.DockerClient(base_url=dockersock)
-    cAttrsbyName = {c.attrs['Name']: c.attrs for c in client.containers.list()}
-    cAttrsbyId = {c.id: c.attrs for c in client.containers.list()}
-    if targetContainer in cAttrsbyName.keys():
-        targetContAttrs = cAttrsbyName[targetContainer]
-    elif targetContainer in cAttrsbyId.keys():
-        targetContAttrs = cAttrsbyId[targetContainer]
-    if sourceContainer in cAttrsbyName.keys():
-        sourceContAttrs = cAttrsbyName[sourceContainer]
-    elif sourceContainer in cAttrsbyId.keys():
-        sourceContAttrs = cAttrsbyId[sourceContainer]
 
 
 def prepare(serviceConfig, serviceState, state):
@@ -68,16 +46,14 @@ def rollover(serviceConfig, serviceState, state):
         if len(destinations) == 0:
             log.error("traefik container misses providers.file.directory argument")
         destination = destinations[0]
-        mounts = [e for e in container.attrs['Mounts'] if os.path.normpath(e['Destination']) == os.path.normpath(destination)]
-        if len(mounts) == 0:
-            log.error("volume missing for providers.file.directory")
-        mount = mounts[0]
 
 
-    traefikProvidersFileDirectory = mount['Source'] if 'auto' == serviceConfig['dirext'] else serviceConfig['dirext'] #'./configuration'
+    traefikProvidersFileDirectory = dch.dockerPathMap('/'+serviceConfig['container'], destination)[0]
+
+    #traefikProvidersFileDirectory = mount['Source'] if 'auto' == serviceConfig['dirext'] else serviceConfig['dirext'] #'./configuration'
     traefikConfigFilename = os.path.join(traefikProvidersFileDirectory,'files/configuration.toml')
     traefikCertDir = os.path.join(traefikProvidersFileDirectory,'certs')
-    traefikProvidersFileDirectoryMount = mount['Destination'] if 'auto' == serviceConfig['dirint'] else serviceConfig['dirint'] # '/configuration'
+    traefikProvidersFileDirectoryMount = os.path.normpath(destination) if 'auto' == serviceConfig['dirint'] else serviceConfig['dirint'] # '/configuration'
     traefikConfigFilenameMount = os.path.join(traefikProvidersFileDirectoryMount,'files/configuration.toml')
     traefikCertDirMount = os.path.join(traefikProvidersFileDirectoryMount,'certs')
 
@@ -105,15 +81,7 @@ def rollover(serviceConfig, serviceState, state):
         with open(os.path.join(traefikProvidersFileDirectory,'reloadtrigger'), 'w') as f:
             f.write('')
 
-    #print(tcfc)
     log.info('  -> Traefik reload')
-    try:
-        pass
-        #rv = check_output(('systemctl', 'start', 'apache2'))
-        #rv = check_output(('systemctl', 'reload', 'apache2'))
-    except CalledProcessError as e:
-        log.error(e.output)
-        raise(e)
     serviceState.setOpStateDone()
 
 def cleanup(serviceConfig, serviceState, state):
